package
Version:
v0.0.0-...-55ff46c
Opens a new window with list of versions in this module.
Published: Jan 14, 2022
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GenerateNewSessionId 生成新会话ID(令牌)
IsSessionExpired 会话是否过期 判断
func LoadSessionsFromDB()
LoadSessionsFromDB 加载所有 Session 并写入 Map
Source Files
¶
Click to show internal directories.
Click to hide internal directories.